Operator
========

.. currentmodule:: chaospy

Multivariate
------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   J
   Iid

Mathematical
------------

.. autosummary::
   :template: distribution.rst
   :toctree: ../../api

   Add
   Multiply
   Negative
   Power
   Trunc
   Log
   Log10
   Logn
